from .core.aws.eks.aws_eks_runner import AWSEKSRunner


def finder(cloud, resource, name):
    if ( cloud == "aws" or cloud == "AWS" ) and ( resource == "eks" or resource == "EKS" ):
        runner = AWSEKSRunner(name)
        return runner
    else:
        return False



from ..aws_eks_check import AWSEKSCheck
from ....core_enums import CheckResult

class ServiceSecretsCheck(AWSEKSCheck):
    def __init__(self, resource_name, context):
        super().__init__(resource_name, context)
        self.name = "service-secrets"

    def scan_logic(self):
        encryption_config = self.context.cluster_description["cluster"].get("encryptionConfig")
        if encryption_config is None:
            self.result = CheckResult.FAIL
            return
        for config in encryption_config:
            resources = config.get("resources")
            for resource in resources:
                if resource == "secrets":
                    self.result = CheckResult.PASS
                    return
        self.result = CheckResult.FAIL




from setuptools import setup
from setuptools import find_packages

setup(
    name='sek',
    version='0.0.14',
    author="Nick Gibbon",
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'sek = sek.main:main',
        ],
    }
)



from ..aws_eks_check import AWSEKSCheck
from ....core_enums import CheckResult

class ServiceLoggingCheck(AWSEKSCheck):
    def __init__(self, resource_name, context):
        super().__init__(resource_name, context)
        self.name = "service-logging"

    def scan_logic(self):
        cluster_logging = self.context.cluster_description["cluster"]["logging"]["clusterLogging"]
        for log_config in cluster_logging:
            if log_config.get("enabled") is False:
                self.result = CheckResult.FAIL
                return
        self.result = CheckResult.PASS
